@@ -84,9 +84,11 @@ int sa_reset_cpus() {
 		return ENOSYS;
 	if (cpus == NULL || number_cpus != new_number_cpus) {
 		number_cpus = new_number_cpus;
-		cpus = realloc(cpus, number_cpus * sizeof(CPU_t));
-		if (cpus == NULL)
+		CPU_t* temp_cpus;
+		temp_cpus = realloc(cpus, number_cpus * sizeof(CPU_t));
+		if (temp_cpus == NULL)
 			return ENOMEM;
+		cpus = temp_cpus;
 	}
 
 	return 0;
