@@ -76,9 +76,8 @@ int sa_count_net_interfaces(uint16_t* number) {
 }
 
 int sa_reset_net_interfaces() {
-	if (fflush(file_net_dev) != 0)
-		return EIO;
-	fseek(file_net_dev, pos_useful_data, SEEK_SET);
+	if (fseek(file_net_dev, pos_useful_data, SEEK_SET) != 0)
+		return ENOSYS;
 	return 0;
 }
 
